summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2019-11-17 16:17:57 +0000
committerKarl Berry <karl@freefriends.org>2019-11-17 16:17:57 +0000
commit67a8f35d803320fb317eb344f0b4e81f10111b28 (patch)
treef094a1a217187336702682835048d044301f3478
parentea26ac45bb36d0da742e6ee47826fa99735c02ed (diff)
split luajittex to its own package
git-svn-id: svn://tug.org/texlive/trunk@52829 c570f23f-e606-0410-a88d-b1316a301751
-rwxr-xr-xMaster/texmf-dist/scripts/texlive/tlmgr.pl4
-rw-r--r--Master/tlpkg/tlpsrc/collection-binextra.tlpsrc1
-rw-r--r--Master/tlpkg/tlpsrc/luajittex.tlpsrc28
-rw-r--r--Master/tlpkg/tlpsrc/luatex.tlpsrc26
-rw-r--r--Master/tlpkg/tlpsrc/mflua.tlpsrc5
5 files changed, 37 insertions, 27 deletions
diff --git a/Master/tlpkg/tlpsrc/collection-binextra.tlpsrc b/Master/tlpkg/tlpsrc/collection-binextra.tlpsrc
index bd3123b7aab..e9a225396ba 100644
--- a/Master/tlpkg/tlpsrc/collection-binextra.tlpsrc
+++ b/Master/tlpkg/tlpsrc/collection-binextra.tlpsrc
@@ -57,6 +57,7 @@ depend latexindent
depend ltxfileinfo
depend ltximg
depend listings-ext
+depend luajittex
depend make4ht
depend match_parens
depend mflua
diff --git a/Master/tlpkg/tlpsrc/luajittex.tlpsrc b/Master/tlpkg/tlpsrc/luajittex.tlpsrc
new file mode 100644
index 00000000000..484761d23ba
--- /dev/null
+++ b/Master/tlpkg/tlpsrc/luajittex.tlpsrc
@@ -0,0 +1,28 @@
+category TLCore
+
+# must keep in sync with luatex.tlpsrc.
+tlpsetvar fmtdeps cm,etex,hyphen-base,knuth-lib,plain,tex-ini-files,\
+unicode-data
+
+# keep in sync with mflua.tlpsrc.
+tlpsetvar no_luajit_platforms x86_64-solaris
+#
+binpattern f/!${no_luajit_platforms} bin/${ARCH}/luajittex
+binpattern f/!${no_luajit_platforms} bin/${ARCH}/texluajit
+binpattern f/!${no_luajit_platforms} bin/${ARCH}/texluajitc
+#
+binpattern f bin/win32/luajit51.dll
+binpattern f bin/win32/luajittex.dll
+#
+binpattern f/i386-cygwin bin/i386-cygwin/cygtexluajit*.dll
+binpattern f/x86_64-cygwin bin/x86_64-cygwin/cygtexluajit*.dll
+
+# On platforms where there is no luajittex, it will be ignored
+# due to the special --no-error-if-no-engine option in fmtutil,
+# invoked by specifications in TLConfig.pm and tlmgr.pl.
+execute AddFormat name=luajittex engine=luajittex options="luatex.ini" \
+ patterns=language.def,language.dat.lua \
+ fmttriggers=${fmtdeps}
+
+# can't have luajittex without luatex.
+depend luatex
diff --git a/Master/tlpkg/tlpsrc/luatex.tlpsrc b/Master/tlpkg/tlpsrc/luatex.tlpsrc
index 74daa3b019f..a58e4902351 100644
--- a/Master/tlpkg/tlpsrc/luatex.tlpsrc
+++ b/Master/tlpkg/tlpsrc/luatex.tlpsrc
@@ -1,5 +1,6 @@
category TLCore
#
+# keep in sync with luajit.tlpsrc.
tlpsetvar fmtdeps cm,etex,hyphen-base,knuth-lib,plain,tex-ini-files,\
unicode-data
#
@@ -11,13 +12,6 @@ execute AddFormat name=dviluatex engine=luatex options="dviluatex.ini" \
patterns=language.def,language.dat.lua \
fmttriggers=${fmtdeps}
#
-# On platforms where there is no luajittex, it will be ignored
-# due to the special --no-error-if-no-engine option in fmtutil,
-# invoked by specifications in TLConfig.pm and tlmgr.pl.
-execute AddFormat name=luajittex engine=luajittex options="luatex.ini" \
- patterns=language.def,language.dat.lua \
- fmttriggers=${fmtdeps}
-#
docpattern d texmf-dist/doc/luatex/base
docpattern f texmf-dist/doc/man/man1/luatex.*
docpattern f texmf-dist/doc/man/man1/texlua*
@@ -31,26 +25,14 @@ binpattern f bin/${ARCH}/luatex
binpattern f bin/${ARCH}/texlua
binpattern f bin/${ARCH}/texluac
#
-binpattern f/i386-cygwin bin/i386-cygwin/cygtexlua*.dll
-binpattern f/x86_64-cygwin bin/x86_64-cygwin/cygtexlua*.dll
-#
-# luahbtex.dll in latex-bin-dev until TL'20, so not:
-# binpattern f bin/win32/lua*.dll
binpattern f bin/win32/lua53.dll
-binpattern f bin/win32/luajit51.dll
-binpattern f bin/win32/luajittex.dll
binpattern f bin/win32/luatex.dll
#
+binpattern f/i386-cygwin bin/i386-cygwin/cygtexlua5*.dll
+binpattern f/x86_64-cygwin bin/x86_64-cygwin/cygtexlua5*.dll
+#
# Visual Studio 2015 (for C++11) dlls for LuaTeX.
binpattern f bin/win32/api-ms-win-*.dll
binpattern f bin/win32/pdfddeservername.txt
binpattern f bin/win32/ucrtbase.dll
binpattern f bin/win32/vcruntime140.dll
-
-# duplicated in mflua.tlpsrc, sigh.
-tlpsetvar no_luajit_platforms \
- x86_64-solaris
-#
-binpattern f/!${no_luajit_platforms} bin/${ARCH}/luajittex
-binpattern f/!${no_luajit_platforms} bin/${ARCH}/texluajit
-binpattern f/!${no_luajit_platforms} bin/${ARCH}/texluajitc
diff --git a/Master/tlpkg/tlpsrc/mflua.tlpsrc b/Master/tlpkg/tlpsrc/mflua.tlpsrc
index 5a2eb3af9ca..ccfaa691712 100644
--- a/Master/tlpkg/tlpsrc/mflua.tlpsrc
+++ b/Master/tlpkg/tlpsrc/mflua.tlpsrc
@@ -15,9 +15,8 @@ runpattern d texmf-dist/metafont/mflua
binpattern f bin/${ARCH}/mflua
binpattern f bin/${ARCH}/mflua-nowin
-# duplicated in luatex.tlpsrc, sigh.
-tlpsetvar no_luajit_platforms \
- x86_64-solaris
+# keep in sync with luatex.tlpsrc.
+tlpsetvar no_luajit_platforms x86_64-solaris
#
binpattern f/!${no_luajit_platforms} bin/${ARCH}/mfluajit
binpattern f/!${no_luajit_platforms} bin/${ARCH}/mfluajit-nowin
diff --git a/Master/texmf-dist/scripts/texlive/tlmgr.pl b/Master/texmf-dist/scripts/texlive/tlmgr.pl
index 0d317b378d9..e7f9aa38e14 100755
--- a/Master/texmf-dist/scripts/texlive/tlmgr.pl
+++ b/Master/texmf-dist/scripts/texlive/tlmgr.pl
@@ -5686,7 +5686,7 @@ sub check_executes {
# luahbtex is special until we build it everywhere for TL'20.
#
# We do not want to have error messages here, so we do the following:
# * if tlpkg/tlpsrc/luatex.tlpsrc is available, then load it
# and filter away those archs that are excluded with f/!...
# * similarly for the other partial-support engines; too much
# trouble to reverse-map to package names, so just hardwire;
@@ -5694,7 +5694,7 @@ sub check_executes {
# the development tree) we just ignore it completely.
my $pkg;
if ($engine eq "luajittex") {
- $pkg = "luatex";
+ $pkg = "luajittex";
} elsif ($engine eq "luahbtex") {
$pkg = "latex-bin-dev";
} elsif ($engine eq "mfluajit") {
@@ -5686,7 +5686,7 @@ sub check_executes {
#
# We do not want to have error messages here, so we do the following:
- # * if tlpkg/tlpsrc/luatex.tlpsrc is available, then load it
+ # * if tlpkg/tlpsrc/luajittex.tlpsrc is available, then load it
# and filter away those archs that are excluded with f/!...
# * similarly for the other partial-support engines; too much